MakePath

Struct MakePath 

pub struct MakePath<'a> { /* private fields */ }
A host feature that allocates absolute file paths.

This is only useful in conjunction with the FreePath and MapPath features. Therefore, the interface of this feature is private and only exposed by a PathManager, which is constructed from these three host features.

Please take a look at the module documentation for a usage example.