RetrieveHandle

Struct RetrieveHandle 

pub struct RetrieveHandle<'a> { /* private fields */ }
Property retrieval handle.

Implementations

Source

impl<'a> RetrieveHandle<'a>

pub fn new( retrieve_fn: LV2_State_Retrieve_Function, handle: LV2_State_Handle, ) -> Self

Create a new retrieval handle that uses the given callback function and handle.

pub fn retrieve<K: ?Sized>( &self, key: URID<K>, ) -> Result<StatePropertyReader<'_>, StateErr>

Try to retrieve a property from the host.

This method calls the internal retrieve callback with the given URID. If there’s no property with the given URID, Err(StateErr::NoProperty) is returned. Otherwise, a reading handle is returned that contains the type and the data of the property and can interpret it as an atom.