StateDescriptor

Struct StateDescriptor 

pub struct StateDescriptor<P: State> { /* private fields */ }
Raw wrapper of the State extension.

This is a marker type that has the required external methods for the extension.

Implementations

Source

impl<P: State> StateDescriptor<P>

pub unsafe extern "C" fn extern_save( instance: LV2_Handle, store: LV2_State_Store_Function, handle: LV2_State_Handle, flags: u32, features: *const *const LV2_Feature, ) -> LV2_State_Status

Handle a save request by the host.

This involves creating the plugin reference, constructing the store handle and discovering the required host features.

Safety

This method is unsafe since it is an interface for hosts written in C and since it dereferences raw pointers.

pub unsafe extern "C" fn extern_restore( instance: LV2_Handle, retrieve: LV2_State_Retrieve_Function, handle: LV2_State_Handle, flags: u32, features: *const *const LV2_Feature, ) -> LV2_State_Status

Handle a restore request by the host.

This involves creating the plugin reference, constructing the retrieve handle and discovering the required host features.

Safety

This method is unsafe since it is an interface for hosts written in C and since it dereferences raw pointers.