StatePropertyReader

Struct StatePropertyReader 

pub struct StatePropertyReader<'a> { /* private fields */ }
Reading handle for properties.

This handle contains the type and the data of a property retrieved from the RetrieveHandle.

Implementations

Source

impl<'a> StatePropertyReader<'a>

pub fn new<T: ?Sized>(type_: URID<T>, body: Space<'a>) -> Self

Create a new reading handle with the given type and data.

pub fn type_(&self) -> URID

Return the type of the property.

pub fn body(&self) -> Space<'_>

Return the data of the property.

pub fn read<A: Atom<'a, 'a>>( &self, urid: URID<A>, parameter: A::ReadParameter, ) -> Result<A::ReadHandle, StateErr>

Try to interpret the property as an atom.

This works like any atom reader: You pass the URID of the atom type as well as the type-specific argument, and if the desired type is the actual type of the data, a read handle is returned.

If the desired and actual data types don’t match, Err(StateErr::BadType) is returned.