pub struct StatePropertyWriter<'a> { /* private fields */ }Expand description
Writing handle for properties.
Implementations
Sourceimpl<'a> StatePropertyWriter<'a>
impl<'a> StatePropertyWriter<'a>
Sourcepub fn new(head: SpaceHead<'a>) -> Self
pub fn new(head: SpaceHead<'a>) -> Self
Create a new property writer that uses the given space head.
Sourcepub fn init<'b, A: Atom<'a, 'b>>(
&'b mut self,
urid: URID<A>,
parameter: A::WriteParameter,
) -> Result<A::WriteHandle, StateErr>
pub fn init<'b, A: Atom<'a, 'b>>( &'b mut self, urid: URID<A>, parameter: A::WriteParameter, ) -> Result<A::WriteHandle, StateErr>
Initialize the property.
This works like any other atom writer: You have to provide the URID of the atom type you want to write, as well as the type-specific parameter. If the property hasn’t been initialized before, it will be initialized and the writing handle is returned. Otherwise, Err(StateErr::Unknown) is returned.