pub enum StateErr {
Unknown,
BadCallback,
BadData,
BadType,
BadFlags,
NoFeature,
NoProperty,
NoSpace,
PathNotUTF8,
HostError,
}Expand description
Kinds of errors that may occur in the crate.
Variants
Unknown
The kind of the error is unknown or doesn’t have a representation.
BadCallback
A callback function pointer of a method is bad.
BadData
Retrieved data is invalid.
BadType
The retrieved data doesn’t have the correct type.
BadFlags
The flags a method was called with are invalid.
NoFeature
A feature the plugin requested is missing.
NoProperty
A property the plugin is requesting doesn’t exist.
NoSpace
There isn’t enough memory available to execute the task.
PathNotUTF8
A path that’s been used as a parameter is not encoded in UTF-8.
HostError
The host does not comply to the specification.
Implementations