pub struct FreePath<'a> { /* private fields */ }Expand description
A host feature that deallocates absolute and abstract file paths.
This is only useful in conjunction with the MapPath and MakePath features. Therefore, the interface of this feature is private and only exposed by a PathManager, which is constructed from these three host features.
Please take a look at the module documentation for a usage example.